Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(643)

Unified Diff: content/browser/service_worker/service_worker_client_utils.h

Issue 2893823004: [Payments] Implement openWindow for service worker based payment handler (Closed)
Patch Set: address comments Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/service_worker/service_worker_client_utils.h
diff --git a/content/browser/service_worker/service_worker_client_utils.h b/content/browser/service_worker/service_worker_client_utils.h
index be46f6c13e78b3ce44d5ece4aac6f074d98e4f60..24697191e176c4c8f9e03ac05e25acdfce37d4f9 100644
--- a/content/browser/service_worker/service_worker_client_utils.h
+++ b/content/browser/service_worker/service_worker_client_utils.h
@@ -37,9 +37,11 @@ using ClientsCallback = base::Callback<void(ServiceWorkerClients* clients)>;
void FocusWindowClient(ServiceWorkerProviderHost* provider_host,
const ClientCallback& callback);
-// Opens a new window and navigates it to |url|. |callback| is called with the
-// window's client information on completion.
-void OpenWindow(const GURL& url,
+// Opens a new window and navigates it to |url|. |redirect_url| is the last
+// navigation occured before |url|. |callback| is called with the window's
+// client information on completion.
+void OpenWindow(const GURL& redirect_url,
+ const GURL& url,
const GURL& script_url,
int worker_process_id,
const base::WeakPtr<ServiceWorkerContextCore>& context,

Powered by Google App Engine
This is Rietveld 408576698